spoon.ber.tag

Package spoon :: Package ber :: Module tag |
[show private | hide private]
[frames | no frames]

## Module spoon.ber.tag

Classes
`Tag` | Representation of the header of an ASN.1 object.

Variable Summary
`dict` | `_class_name` = `{0: 'UNIVERSAL', 1: 'APPLICATION', 2: 'CON...`

Variable Details

    ### _class_name Type: `dict` Value:
        {0: 'UNIVERSAL', 1: 'APPLICATION', 2: 'CONTEXT', 3: 'PRIVATE'}

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net